# Facebook Report

Pequeño programa para generar un documento .docx con datos relevantes para juzgar el desempeño de una fanpage de Facebook.

## Uso

El programa requiere descargar (el acceso online a los datos está en desarrollo) los datos que Facebook ofrece, tanto a nivel página como a nivel post, en formato .csv. Es requisito que los datos recabados en ambos archivos correspondan a las mismas fechas de inicio y término.

A su vez, el programa requiere seleccionar uno de los cuatro criterios disponibles para presentar el post con mayor desempeño durante el periodo analizado. Estos son impresiones, usuarios que interactuaron, alcance y tasa de participación.

